@@ -3,7 +3,7 @@
  *
  * File GPSSERIO.H Copyright (c) by Meinberg Funkuhren (www.meinberg.de)
  * Copyright 2015 by the NTPsec project contributors
- * SPDX-License-Identifier: BSD-3-clause
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Linkage to PARSE:
  * Copyright (c) 1997-2005 by Frank Kardel <kardel <AT> ntp.org>
@@ -89,28 +89,27 @@ typedef uint16_t GPS_CMD;
  *
  * @see ::GPS_CMD_CODES_TABLE
  */
-enum GPS_CMD_CODES
-{ /* system data */
-  GPS_AUTO_ON = 0x000,  ///< (-w-) no data, enable auto-msgs from device
-  GPS_AUTO_OFF,         ///< (-w-) no data, disable auto-msgs from device
-  GPS_SW_REV,           ///< (r--) deprecated, ::SW_REV, software revision, use only if ::GPS_RECEIVER_INFO not supp.
-  GPS_BVAR_STAT,        ///< (r--) ::BVAR_STAT, status of buffered variables, only if ::GPS_MODEL_HAS_BVAR_STAT
-  GPS_TIME,             ///< (-wa) ::TTM, current time or capture, or init board time
-  GPS_POS_XYZ,          ///< (rw-) ::XYZ, current position in ECEF coordinates, only if ::GPS_MODEL_HAS_POS_XYZ
-  GPS_POS_LLA,          ///< (rw-) ::LLA, current position in geographic coordinates, only if ::GPS_MODEL_HAS_POS_LLA
-  GPS_TZDL,             ///< (rw-) ::TZDL, time zone / daylight saving, only if ::GPS_MODEL_HAS_TZDL
-  GPS_PORT_PARM,        ///< (rw-) deprecated, ::PORT_PARM, use ::PORT_SETTINGS etc. if ::GPS_RECEIVER_INFO supported
-  GPS_SYNTH,            ///< (rw-) ::SYNTH, synthesizer settings, only if ::GPS_HAS_SYNTH
-  GPS_ANT_INFO,         ///< (r-a) ::ANT_INFO, time diff after antenna disconnect, only if ::GPS_MODEL_HAS_ANT_INFO
-  GPS_UCAP,             ///< (r-a) ::TTM, user capture events, only if ::RECEIVER_INFO::n_ucaps > 0
+enum GPS_CMD_CODES { /* system data */
+    GPS_AUTO_ON = 0x000,  ///< (-w-) no data, enable auto-msgs from device
+    GPS_AUTO_OFF,         ///< (-w-) no data, disable auto-msgs from device
+    GPS_SW_REV,           ///< (r--) deprecated, ::SW_REV, software revision, use only if ::GPS_RECEIVER_INFO not supp.
+    GPS_BVAR_STAT,        ///< (r--) ::BVAR_STAT, status of buffered variables, only if ::GPS_MODEL_HAS_BVAR_STAT
+    GPS_TIME,             ///< (-wa) ::TTM, current time or capture, or init board time
+    GPS_POS_XYZ,          ///< (rw-) ::XYZ, current position in ECEF coordinates, only if ::GPS_MODEL_HAS_POS_XYZ
+    GPS_POS_LLA,          ///< (rw-) ::LLA, current position in geographic coordinates, only if ::GPS_MODEL_HAS_POS_LLA
+    GPS_TZDL,             ///< (rw-) ::TZDL, time zone / daylight saving, only if ::GPS_MODEL_HAS_TZDL
+    GPS_PORT_PARM,        ///< (rw-) deprecated, ::PORT_PARM, use ::PORT_SETTINGS etc. if ::GPS_RECEIVER_INFO supported
+    GPS_SYNTH,            ///< (rw-) ::SYNTH, synthesizer settings, only if ::GPS_HAS_SYNTH
+    GPS_ANT_INFO,         ///< (r-a) ::ANT_INFO, time diff after antenna disconnect, only if ::GPS_MODEL_HAS_ANT_INFO
+    GPS_UCAP,             ///< (r-a) ::TTM, user capture events, only if ::RECEIVER_INFO::n_ucaps > 0
 
-  /* GPS data */
-  GPS_CFGH = 0x100,     ///< (rw-) ::CFGH, SVs' configuration and health codes
-  GPS_ALM,              ///< (rw-) req: uint16_t SV num, ::SV_ALM, one SV's almanac
-  GPS_EPH,              ///< (rw-) req: uint16_t SV num, ::SV_EPH, one SV's ephemeris
-  GPS_UTC,              ///< (rw-) ::UTC, GPS %UTC correction parameters
-  GPS_IONO,             ///< (rw-) ::IONO, GPS ionospheric correction parameters
-  GPS_ASCII_MSG         ///< (r--) ::ASCII_MSG, the GPS ASCII message
+    /* GPS data */
+    GPS_CFGH = 0x100,     ///< (rw-) ::CFGH, SVs' configuration and health codes
+    GPS_ALM,              ///< (rw-) req: uint16_t SV num, ::SV_ALM, one SV's almanac
+    GPS_EPH,              ///< (rw-) req: uint16_t SV num, ::SV_EPH, one SV's ephemeris
+    GPS_UTC,              ///< (rw-) ::UTC, GPS %UTC correction parameters
+    GPS_IONO,             ///< (rw-) ::IONO, GPS ionospheric correction parameters
+    GPS_ASCII_MSG         ///< (r--) ::ASCII_MSG, the GPS ASCII message
 };
 
 
@@ -120,13 +119,11 @@ typedef uint16_t CSUM;
 /**
  * @brief The header of a binary message.
  */
-typedef struct
-{
-  GPS_CMD cmd;      ///< see ::GPS_CMD_CODES
-  uint16_t len;     ///< length of the data portion appended after the header
-  CSUM data_csum;   ///< checksum of the data portion appended after the header
-  CSUM hdr_csum;    ///< checksum of the preceding header bytes
-
+typedef struct {
+    GPS_CMD cmd;      ///< see ::GPS_CMD_CODES
+    uint16_t len;     ///< length of the data portion appended after the header
+    CSUM data_csum;   ///< checksum of the data portion appended after the header
+    CSUM hdr_csum;    ///< checksum of the preceding header bytes
 } GPS_MSG_HDR;
 
 
@@ -139,12 +136,10 @@ typedef struct
  * Contains a software revision code, plus an optional
  * identifier for a customized version.
  */
-typedef struct
-{
-  uint16_t code;               ///< Version number, e.g. 0x0120 means v1.20
-  char name[GPS_ID_STR_SIZE];  ///< Optional string identifying a customized version
-  uint8_t reserved;            ///< Reserved field to yield even structure size
-
+typedef struct {
+    uint16_t code;               ///< Version number, e.g. 0x0120 means v1.20
+    char name[GPS_ID_STR_SIZE];  ///< Optional string identifying a customized version
+    uint8_t reserved;            ///< Reserved field to yield even structure size
 } SW_REV;
 
 
@@ -154,19 +149,18 @@ typedef struct
  * @todo: Check if MAX_SVNO_GLN is 94 instead of 95, and thus
  *        N_SVNO_GLN is 30 instead of 31, as reported by Wikipedia.
  */
-enum GNSS_SVNOS
-{
-  MIN_SVNO_GPS = 1,       ///< min. GPS satellite PRN number
-  MAX_SVNO_GPS = 32,      ///< max. GPS satellite PRN number
-  N_SVNO_GPS = 32,        ///< max. number of active GPS satellites
+enum GNSS_SVNOS {
+    MIN_SVNO_GPS = 1,       ///< min. GPS satellite PRN number
+    MAX_SVNO_GPS = 32,      ///< max. GPS satellite PRN number
+    N_SVNO_GPS = 32,        ///< max. number of active GPS satellites
 
-  MIN_SVNO_WAAS = 33,     ///< min. WAAS satellite number
-  MAX_SVNO_WAAS = 64,     ///< max. WAAS satellite number
-  N_SVNO_WAAS = 32,       ///< max. number of active WAAS satellites
+    MIN_SVNO_WAAS = 33,     ///< min. WAAS satellite number
+    MAX_SVNO_WAAS = 64,     ///< max. WAAS satellite number
+    N_SVNO_WAAS = 32,       ///< max. number of active WAAS satellites
 
-  MIN_SVNO_GLONASS = 65,  ///< min. Glonass satellite number (64 + sat slot ID)
-  MAX_SVNO_GLONASS = 95,  ///< max. Glonass satellite number (64 + sat slot ID)
-  N_SVNO_GLONASS = 31     ///< max. number of active Glonass satellites
+    MIN_SVNO_GLONASS = 65,  ///< min. Glonass satellite number (64 + sat slot ID)
+    MAX_SVNO_GLONASS = 95,  ///< max. Glonass satellite number (64 + sat slot ID)
+    N_SVNO_GLONASS = 31     ///< max. number of active Glonass satellites
 };
 
 
@@ -202,14 +196,13 @@ typedef uint16_t BVAR_STAT;
  * @see ::BVAR_FLAGS
  * @see ::BVAR_FLAG_NAMES
  */
-enum BVAR_FLAG_BITS
-{
-  BVAR_BIT_CFGH_INVALID,      ///< Satellite configuration and health parameters incomplete
-  BVAR_BIT_ALM_NOT_COMPLETE,  ///< Almanac parameters incomplete
-  BVAR_BIT_UTC_INVALID,       ///< %UTC offset parameters incomplete
-  BVAR_BIT_IONO_INVALID,      ///< Ionospheric correction parameters incomplete
-  BVAR_BIT_RCVR_POS_INVALID,  ///< No valid receiver position available
-  N_BVAR_BIT                  ///< number of defined ::BVAR_STAT bits
+enum BVAR_FLAG_BITS {
+    BVAR_BIT_CFGH_INVALID,      ///< Satellite configuration and health parameters incomplete
+    BVAR_BIT_ALM_NOT_COMPLETE,  ///< Almanac parameters incomplete
+    BVAR_BIT_UTC_INVALID,       ///< %UTC offset parameters incomplete
+    BVAR_BIT_IONO_INVALID,      ///< Ionospheric correction parameters incomplete
+    BVAR_BIT_RCVR_POS_INVALID,  ///< No valid receiver position available
+    N_BVAR_BIT                  ///< number of defined ::BVAR_STAT bits
 };
 
 
@@ -222,13 +215,12 @@ enum BVAR_FLAG_BITS
  * @see ::BVAR_FLAG_BITS
  * @see ::BVAR_FLAG_NAMES
  */
-enum BVAR_FLAGS
-{
-  BVAR_CFGH_INVALID     = ( 1UL << BVAR_BIT_CFGH_INVALID ),      ///< see ::BVAR_BIT_CFGH_INVALID
-  BVAR_ALM_NOT_COMPLETE = ( 1UL << BVAR_BIT_ALM_NOT_COMPLETE ),  ///< see ::BVAR_BIT_ALM_NOT_COMPLETE
-  BVAR_UTC_INVALID      = ( 1UL << BVAR_BIT_UTC_INVALID ),       ///< see ::BVAR_BIT_UTC_INVALID
-  BVAR_IONO_INVALID     = ( 1UL << BVAR_BIT_IONO_INVALID ),      ///< see ::BVAR_BIT_IONO_INVALID
-  BVAR_RCVR_POS_INVALID = ( 1UL << BVAR_BIT_RCVR_POS_INVALID ),  ///< see ::BVAR_BIT_RCVR_POS_INVALID
+enum BVAR_FLAGS {
+    BVAR_CFGH_INVALID     = ( 1UL << BVAR_BIT_CFGH_INVALID ),      ///< see ::BVAR_BIT_CFGH_INVALID
+    BVAR_ALM_NOT_COMPLETE = ( 1UL << BVAR_BIT_ALM_NOT_COMPLETE ),  ///< see ::BVAR_BIT_ALM_NOT_COMPLETE
+    BVAR_UTC_INVALID      = ( 1UL << BVAR_BIT_UTC_INVALID ),       ///< see ::BVAR_BIT_UTC_INVALID
+    BVAR_IONO_INVALID     = ( 1UL << BVAR_BIT_IONO_INVALID ),      ///< see ::BVAR_BIT_IONO_INVALID
+    BVAR_RCVR_POS_INVALID = ( 1UL << BVAR_BIT_RCVR_POS_INVALID ),  ///< see ::BVAR_BIT_RCVR_POS_INVALID
 };
 
 
@@ -249,12 +241,10 @@ enum BVAR_FLAGS
  * of leap seconds is disseminated by the satellites using the ::UTC
  * parameter set, which also provides info on pending leap seconds.
  */
-typedef struct
-{
-  uint16_t wn;     ///< the week number since GPS has been installed
-  uint32_t sec;    ///< the second of that week
-  uint32_t tick;   ///< fractions of a second, 1/::RECEIVER_INFO::ticks_per_sec units
-
+typedef struct {
+    uint16_t wn;     ///< the week number since GPS has been installed
+    uint32_t sec;    ///< the second of that week
+    uint32_t tick;   ///< fractions of a second, 1/::RECEIVER_INFO::ticks_per_sec units
 } T_GPS;
 
 
@@ -271,20 +261,18 @@ typedef struct
  * done if some valid ::UTC correction parameters are available in the
  * receiver's non-volatile memory.
  */
-typedef struct
-{
-  int16_t year;           ///< year number, 0..9999
-  int8_t month;           ///< month, 1..12
-  int8_t mday;            ///< day of month, 1..31
-  int16_t yday;           ///< day of year, 1..365, or 366 in case of leap year
-  int8_t wday;            ///< day of week, 0..6 == Sun..Sat
-  int8_t hour;            ///< hours, 0..23
-  int8_t min;             ///< minutes, 0..59
-  int8_t sec;             ///< seconds, 0..59, or 60 in case of inserted leap second
-  int32_t frac;           ///< fractions of a second, 1/::RECEIVER_INFO::ticks_per_sec units
-  int32_t offs_from_utc;  ///< local time offset from %UTC [sec]
-  uint16_t status;        ///< status flags, see ::TM_GPS_STATUS_BIT_MASKS
-
+typedef struct {
+    int16_t year;           ///< year number, 0..9999
+    int8_t month;           ///< month, 1..12
+    int8_t mday;            ///< day of month, 1..31
+    int16_t yday;           ///< day of year, 1..365, or 366 in case of leap year
+    int8_t wday;            ///< day of week, 0..6 == Sun..Sat
+    int8_t hour;            ///< hours, 0..23
+    int8_t min;             ///< minutes, 0..59
+    int8_t sec;             ///< seconds, 0..59, or 60 in case of inserted leap second
+    int32_t frac;           ///< fractions of a second, 1/::RECEIVER_INFO::ticks_per_sec units
+    int32_t offs_from_utc;  ///< local time offset from %UTC [sec]
+    uint16_t status;        ///< status flags, see ::TM_GPS_STATUS_BIT_MASKS
 } TM_GPS;
 
 
@@ -297,25 +285,24 @@ typedef struct
  *
  * @see ::TM_GPS_STATUS_BIT_MASKS
  */
-enum TM_GPS_STATUS_BITS
-{
-  TM_BIT_UTC,          ///< %UTC correction has been made
-  TM_BIT_LOCAL,        ///< %UTC has been converted to local time according to ::TZDL settings
-  TM_BIT_DL_ANN,       ///< state of daylight saving is going to change
-  TM_BIT_DL_ENB,       ///< daylight saving is in effect
-  TM_BIT_LS_ANN,       ///< leap second pending
-  TM_BIT_LS_ENB,       ///< current second is leap second
-  TM_BIT_LS_ANN_NEG,   ///< set in addition to ::TM_BIT_LS_ANN if leap sec is negative
-  TM_BIT_INVT,         ///< invalid time, e.g. if RTC battery bas been empty
+enum TM_GPS_STATUS_BITS {
+    TM_BIT_UTC,          ///< %UTC correction has been made
+    TM_BIT_LOCAL,        ///< %UTC has been converted to local time according to ::TZDL settings
+    TM_BIT_DL_ANN,       ///< state of daylight saving is going to change
+    TM_BIT_DL_ENB,       ///< daylight saving is in effect
+    TM_BIT_LS_ANN,       ///< leap second pending
+    TM_BIT_LS_ENB,       ///< current second is leap second
+    TM_BIT_LS_ANN_NEG,   ///< set in addition to ::TM_BIT_LS_ANN if leap sec is negative
+    TM_BIT_INVT,         ///< invalid time, e.g. if RTC battery bas been empty
 
-  TM_BIT_EXT_SYNC,     ///< synchronized externally
-  TM_BIT_HOLDOVER,     ///< in holdover mode after previous synchronization
-  TM_BIT_ANT_SHORT,    ///< antenna cable short circuited
-  TM_BIT_NO_WARM,      ///< OCXO has not warmed up
-  TM_BIT_ANT_DISCONN,  ///< antenna currently disconnected
-  TM_BIT_SYN_FLAG,     ///< TIME_SYN output is low
-  TM_BIT_NO_SYNC,      ///< time sync actually not verified
-  TM_BIT_NO_POS        ///< position actually not verified, LOCK LED off
+    TM_BIT_EXT_SYNC,     ///< synchronized externally
+    TM_BIT_HOLDOVER,     ///< in holdover mode after previous synchronization
+    TM_BIT_ANT_SHORT,    ///< antenna cable short circuited
+    TM_BIT_NO_WARM,      ///< OCXO has not warmed up
+    TM_BIT_ANT_DISCONN,  ///< antenna currently disconnected
+    TM_BIT_SYN_FLAG,     ///< TIME_SYN output is low
+    TM_BIT_NO_SYNC,      ///< time sync actually not verified
+    TM_BIT_NO_POS        ///< position actually not verified, LOCK LED off
 };
 
 
@@ -327,25 +314,24 @@ enum TM_GPS_STATUS_BITS
  *
  * @see ::TM_GPS_STATUS_BITS
  */
-enum TM_GPS_STATUS_BIT_MASKS
-{
-  TM_UTC         = ( 1UL << TM_BIT_UTC ),          ///< see ::TM_BIT_UTC
-  TM_LOCAL       = ( 1UL << TM_BIT_LOCAL ),        ///< see ::TM_BIT_LOCAL
-  TM_DL_ANN      = ( 1UL << TM_BIT_DL_ANN ),       ///< see ::TM_BIT_DL_ANN
-  TM_DL_ENB      = ( 1UL << TM_BIT_DL_ENB ),       ///< see ::TM_BIT_DL_ENB
-  TM_LS_ANN      = ( 1UL << TM_BIT_LS_ANN ),       ///< see ::TM_BIT_LS_ANN
-  TM_LS_ENB      = ( 1UL << TM_BIT_LS_ENB ),       ///< see ::TM_BIT_LS_ENB
-  TM_LS_ANN_NEG  = ( 1UL << TM_BIT_LS_ANN_NEG ),   ///< see ::TM_BIT_LS_ANN_NEG
-  TM_INVT        = ( 1UL << TM_BIT_INVT ),         ///< see ::TM_BIT_INVT
+enum TM_GPS_STATUS_BIT_MASKS {
+    TM_UTC         = ( 1UL << TM_BIT_UTC ),          ///< see ::TM_BIT_UTC
+    TM_LOCAL       = ( 1UL << TM_BIT_LOCAL ),        ///< see ::TM_BIT_LOCAL
+    TM_DL_ANN      = ( 1UL << TM_BIT_DL_ANN ),       ///< see ::TM_BIT_DL_ANN
+    TM_DL_ENB      = ( 1UL << TM_BIT_DL_ENB ),       ///< see ::TM_BIT_DL_ENB
+    TM_LS_ANN      = ( 1UL << TM_BIT_LS_ANN ),       ///< see ::TM_BIT_LS_ANN
+    TM_LS_ENB      = ( 1UL << TM_BIT_LS_ENB ),       ///< see ::TM_BIT_LS_ENB
+    TM_LS_ANN_NEG  = ( 1UL << TM_BIT_LS_ANN_NEG ),   ///< see ::TM_BIT_LS_ANN_NEG
+    TM_INVT        = ( 1UL << TM_BIT_INVT ),         ///< see ::TM_BIT_INVT
 
-  TM_EXT_SYNC    = ( 1UL << TM_BIT_EXT_SYNC ),     ///< see ::TM_BIT_EXT_SYNC
-  TM_HOLDOVER    = ( 1UL << TM_BIT_HOLDOVER ),     ///< see ::TM_BIT_HOLDOVER
-  TM_ANT_SHORT   = ( 1UL << TM_BIT_ANT_SHORT ),    ///< see ::TM_BIT_ANT_SHORT
-  TM_NO_WARM     = ( 1UL << TM_BIT_NO_WARM ),      ///< see ::TM_BIT_NO_WARM
-  TM_ANT_DISCONN = ( 1UL << TM_BIT_ANT_DISCONN ),  ///< see ::TM_BIT_ANT_DISCONN
-  TM_SYN_FLAG    = ( 1UL << TM_BIT_SYN_FLAG ),     ///< see ::TM_BIT_SYN_FLAG
-  TM_NO_SYNC     = ( 1UL << TM_BIT_NO_SYNC ),      ///< see ::TM_BIT_NO_SYNC
-  TM_NO_POS      = ( 1UL << TM_BIT_NO_POS )        ///< see ::TM_BIT_NO_POS
+    TM_EXT_SYNC    = ( 1UL << TM_BIT_EXT_SYNC ),     ///< see ::TM_BIT_EXT_SYNC
+    TM_HOLDOVER    = ( 1UL << TM_BIT_HOLDOVER ),     ///< see ::TM_BIT_HOLDOVER
+    TM_ANT_SHORT   = ( 1UL << TM_BIT_ANT_SHORT ),    ///< see ::TM_BIT_ANT_SHORT
+    TM_NO_WARM     = ( 1UL << TM_BIT_NO_WARM ),      ///< see ::TM_BIT_NO_WARM
+    TM_ANT_DISCONN = ( 1UL << TM_BIT_ANT_DISCONN ),  ///< see ::TM_BIT_ANT_DISCONN
+    TM_SYN_FLAG    = ( 1UL << TM_BIT_SYN_FLAG ),     ///< see ::TM_BIT_SYN_FLAG
+    TM_NO_SYNC     = ( 1UL << TM_BIT_NO_SYNC ),      ///< see ::TM_BIT_NO_SYNC
+    TM_NO_POS      = ( 1UL << TM_BIT_NO_POS )        ///< see ::TM_BIT_NO_POS
 };
 
 
@@ -417,25 +403,22 @@ typedef char TZ_NAME[6];
  * before resynchronization, i.e. how much the internal
  * time has drifted while the antenna was disconnected.
  */
-typedef struct
-{
-  int16_t status;      ///< current status of antenna, see ::ANT_STATUS_CODES
-  TM_GPS tm_disconn;   ///< time of antenna disconnect
-  TM_GPS tm_reconn;    ///< time of antenna reconnect
-  int32_t delta_t;     ///< clock offs at reconn. time in 1/::RECEIVER_INFO::ticks_per_sec units
-
+typedef struct {
+    int16_t status;      ///< current status of antenna, see ::ANT_STATUS_CODES
+    TM_GPS tm_disconn;   ///< time of antenna disconnect
+    TM_GPS tm_reconn;    ///< time of antenna reconnect
+    int32_t delta_t;     ///< clock offs at reconn. time in 1/::RECEIVER_INFO::ticks_per_sec units
 } ANT_INFO;
 
 
 /**
  * @brief Status code used with ::ANT_INFO::status
  */
-enum ANT_STATUS_CODES
-{
-  ANT_INVALID,   ///< No other fields valid since antenna has not yet been disconnected
-  ANT_DISCONN,   ///< Antenna is disconnected, tm_reconn and delta_t not yet set
-  ANT_RECONN,    ///< Antenna has been disconnect, and receiver sync. after reconnect, so all fields valid
-  N_ANT_STATUS_CODES  ///< the number of known status codes
+enum ANT_STATUS_CODES {
+    ANT_INVALID,   ///< No other fields valid since antenna has not yet been disconnected
+    ANT_DISCONN,   ///< Antenna is disconnected, tm_reconn and delta_t not yet set
+    ANT_RECONN,    ///< Antenna has been disconnect, and receiver sync. after reconnect, so all fields valid
+    N_ANT_STATUS_CODES  ///< the number of known status codes
 };
 
 
@@ -443,18 +426,16 @@ enum ANT_STATUS_CODES
 /**
  * @brief Summary of configuration and health data of all satellites
  */
-typedef struct
-{
-  CSUM csum;                  ///< checksum of the remaining bytes
-  int16_t valid;              ///< flag data are valid
+typedef struct {
+    CSUM csum;                  ///< checksum of the remaining bytes
+    int16_t valid;              ///< flag data are valid
 
-  T_GPS tot_51;               ///< time of transmission, page 51
-  T_GPS tot_63;               ///< time of transmission, page 63
-  T_GPS t0a;                  ///< complete reference time almanac
-
-  CFG cfg[N_SVNO_GPS];        ///< 4 bit SV configuration code from page 63
-  HEALTH health[N_SVNO_GPS];  ///< 6 bit SV health codes from pages 51, 63
+    T_GPS tot_51;               ///< time of transmission, page 51
+    T_GPS tot_63;               ///< time of transmission, page 63
+    T_GPS t0a;                  ///< complete reference time almanac
 
+    CFG cfg[N_SVNO_GPS];        ///< 4 bit SV configuration code from page 63
+    HEALTH health[N_SVNO_GPS];  ///< 6 bit SV health codes from pages 51, 63
 } CFGH;
 
 
@@ -497,32 +478,28 @@ typedef struct
  *
  * @note In the original code the type of A0 and A1 is double.
  */
-typedef struct
-{
-  CSUM csum;          ///<  Checksum of the remaining bytes
-  int16_t valid;      ///<  Flag indicating %UTC parameters are valid
+typedef struct {
+    CSUM csum;          ///<  Checksum of the remaining bytes
+    int16_t valid;      ///<  Flag indicating %UTC parameters are valid
 
-  T_GPS t0t;          ///<  Reference Time %UTC Parameters [wn|sec]
-  l_fp A0;            ///<  +- Clock Correction Coefficient 0 [sec]
-  l_fp A1;            ///<  +- Clock Correction Coefficient 1 [sec/sec]
-
-  uint16_t WNlsf;     ///<  Week number of nearest leap second
-  int16_t DNt;        ///<  The day number at the end of which a leap second occurs
-  int8_t delta_tls;   ///<  Current %UTC offset to GPS system time [sec]
-  int8_t delta_tlsf;  ///<  Future %UTC offset to GPS system time after next leap second transition [sec]
+    T_GPS t0t;          ///<  Reference Time %UTC Parameters [wn|sec]
+    l_fp A0;            ///<  +- Clock Correction Coefficient 0 [sec]
+    l_fp A1;            ///<  +- Clock Correction Coefficient 1 [sec/sec]
 
+    uint16_t WNlsf;     ///<  Week number of nearest leap second
+    int16_t DNt;        ///<  The day number at the end of which a leap second occurs
+    int8_t delta_tls;   ///<  Current %UTC offset to GPS system time [sec]
+    int8_t delta_tlsf;  ///<  Future %UTC offset to GPS system time after next leap second transition [sec]
 } UTC;
 
 
 /**
  * @brief GPS ASCII message
  */
-typedef struct
-{
-  CSUM csum;       ///< checksum of the remaining bytes */
-  int16_t valid;   ///< flag data are valid
-  char s[23];      ///< 22 chars GPS ASCII message plus trailing zero
-
+typedef struct {
+    CSUM csum;       ///< checksum of the remaining bytes */
+    int16_t valid;   ///< flag data are valid
+    char s[23];      ///< 22 chars GPS ASCII message plus trailing zero
 } ASCII_MSG;
 
 
