@@ -16,10 +16,9 @@
  * The calling convention is not attractive:
  *     DPRINT(debuglevel, (fmt, ...));
  *     DPRINT(2, ("this will appear on stdout if debug >= %d\n", 2));
- *
- * TPRINT is used where the logger needs to remain even when DEBUG is off.
  */
 #ifdef DEBUG
+extern int debug;
 #define DPRINT(lvl, arg)					\
 	do { 						\
 		if (debug >= (lvl))			\
@@ -29,10 +28,4 @@
 #define DPRINT(lvl, arg)	do {} while (0)
 #endif  /* DEBUG */
 
-#define TPRINT(lvl, arg)				\
-	do { 						\
-		if (debug >= (lvl))			\
-			printf arg;			\
-	} while (0)
-
 #endif	/* GUARD_NTP_DEBUG_H */
