@@ -76,13 +76,13 @@ ntp_set_tod(
 	int		rc;
 	int		saved_errno;
 
-	TPRINT(1, ("In ntp_set_tod\n"));
+	DPRINT(1, ("In ntp_set_tod\n"));
 	errno = 0;
 	rc = clock_settime(CLOCK_REALTIME, tvs);
 	saved_errno = errno;
-	TPRINT(1, ("ntp_set_tod: clock_settime: %d %s\n", rc, strerror(errno)));
+	DPRINT(1, ("ntp_set_tod: clock_settime: %d %s\n", rc, strerror(errno)));
 	errno = saved_errno;	/* for strerror(errno)) below */
-	TPRINT(1, ("ntp_set_tod: Final result: clock_settime: %d %s\n", rc, strerror(errno)));
+	DPRINT(1, ("ntp_set_tod: Final result: clock_settime: %d %s\n", rc, strerror(errno)));
 
 	if (rc)
 		errno = saved_errno;
