@@ -24,7 +24,7 @@
 #include "isc_interfaceiter.h"
 #include "isc_netaddr.h"
 #include "isc_result.h"
-#include "isc_error.h"
+#include "ntp_stdlib.h"
 
 
 /* Must follow <isc/net.h>. */
@@ -258,7 +258,7 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
         if (!seenv6) {
                 iter->proc = fopen("/proc/net/if_inet6", "r");
                 if (iter->proc == NULL) {
-			IGNORE(strerror_r(errno, strbuf, sizeof(strbuf)));
+			ntp_strerror_r(errno, strbuf, sizeof(strbuf));
 /*                      isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
                                       ISC_LOGMODULE_SOCKET, ISC_LOG_WARNING,
                                       "failed to open /proc/net/if_inet6");
@@ -277,8 +277,8 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
                         break;
         }
         if (ret < 0) {
-		IGNORE(strerror_r(errno, strbuf, sizeof(strbuf)));
-                UNEXPECTED_ERROR("getting interface addresses: getifaddrs: %s",
+		ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "getting interface addresses: getifaddrs: %s",
                                  strbuf);
                 result = ISC_R_UNEXPECTED;
                 goto failure;
@@ -525,8 +525,8 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
          */
         bufsize = 0;
         if (sysctl(mib, 6, NULL, &bufsize, NULL, (size_t) 0) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("getting interface list size: sysctl: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "getting interface list size: sysctl: %s",
                                  strbuf);
                 result = ISC_R_UNEXPECTED;
                 goto failure;
@@ -541,8 +541,8 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
 
         bufused = bufsize;
         if (sysctl(mib, 6, iter->buf, &bufused, NULL, (size_t) 0) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("getting interface list: sysctl: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "getting interface list: sysctl: %s",
                                  strbuf);
                 result = ISC_R_UNEXPECTED;
                 goto failure;
@@ -848,8 +848,8 @@ getbuf4(isc_interfaceiter_t *iter) {
                 if (isc_ioctl(iter->socket, SIOCGIFCONF, (char *)&iter->ifc)
                     == -1) {
                         if (errno != EINVAL) {
-                                strerror_r(errno, strbuf, sizeof(strbuf));
-                                UNEXPECTED_ERROR("get interface "
+                                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                                msyslog(LOG_ERR, "get interface "
                                                  "configuration: %s",
                                                  strbuf);
                                 goto unexpected;
@@ -872,7 +872,7 @@ getbuf4(isc_interfaceiter_t *iter) {
                                 break;
                 }
                 if (iter->bufsize >= IFCONF_BUFSIZE_MAX) {
-                        UNEXPECTED_ERROR("get interface configuration: "
+                        msyslog(LOG_ERR, "get interface configuration: "
                                          "maximum buffer size exceeded");
                         goto unexpected;
                 }
@@ -918,8 +918,8 @@ getbuf6(isc_interfaceiter_t *iter) {
                 if (isc_ioctl(iter->socket6, SIOCGLIFCONF, (char *)&iter->lifc)
                     == -1) {
                         if (errno != EINVAL) {
-                                strerror_r(errno, strbuf, sizeof(strbuf));
-                                UNEXPECTED_ERROR("get interface "
+                                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                                msyslog(LOG_ERR, "get interface "
                                                  "configuration: %s",
                                                  strbuf);
                                 result = ISC_R_UNEXPECTED;
@@ -943,7 +943,7 @@ getbuf6(isc_interfaceiter_t *iter) {
                                 break;
                 }
                 if (iter->bufsize6 >= IFCONF_BUFSIZE_MAX) {
-                        UNEXPECTED_ERROR("get interface configuration: "
+                        msyslog(LOG_ERR, "get interface configuration: "
                                          "maximum buffer size exceeded");
                         result = ISC_R_UNEXPECTED;
                         goto cleanup;
@@ -1004,8 +1004,8 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
                  * SIOCGLIFCONF to get IPv6 addresses.
                  */
                 if ((iter->socket6 = socket(AF_INET6, SOCK_DGRAM, 0)) < 0) {
-                        strerror_r(errno, strbuf, sizeof(strbuf));
-                        UNEXPECTED_ERROR("making interface scan socket: %s",
+                        ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                        msyslog(LOG_ERR, "making interface scan socket: %s",
                                          strbuf);
                         result = ISC_R_UNEXPECTED;
                         goto socket6_failure;
@@ -1016,8 +1016,8 @@ isc_interfaceiter_create(isc_mem_t *mctx, isc_interfaceiter_t **iterp) {
         }
 #endif
         if ((iter->socket = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("making interface scan socket: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "making interface scan socket: %s",
                                  strbuf);
                 result = ISC_R_UNEXPECTED;
                 goto socket_failure;
@@ -1139,8 +1139,8 @@ internal_current4(isc_interfaceiter_t *iter) {
          * and is really hard to shut up.
          */
         if (isc_ioctl(iter->socket, SIOCGIFFLAGS, (char *) &ifreq) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("%s: getting interface flags: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "%s: getting interface flags: %s",
                                  ifreq.ifr_name, strbuf);
                 return (ISC_R_IGNORE);
         }
@@ -1174,8 +1174,8 @@ internal_current4(isc_interfaceiter_t *iter) {
                sizeof(iter->current.address.type.in6));
 
         if (isc_ioctl(iter->socket, SIOCGLIFADDR, &lifreq) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("%s: getting interface address: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "%s: getting interface address: %s",
                                  ifreq.ifr_name, strbuf);
                 return (ISC_R_IGNORE);
         }
@@ -1213,8 +1213,8 @@ internal_current4(isc_interfaceiter_t *iter) {
                  */
                 if (isc_ioctl(iter->socket, SIOCGIFDSTADDR, (char *)&ifreq)
                     < 0) {
-                        strerror_r(errno, strbuf, sizeof(strbuf));
-                        UNEXPECTED_ERROR("%s: getting destination address: %s",
+                        ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                        msyslog(LOG_ERR, "%s: getting destination address: %s",
                                          ifreq.ifr_name, strbuf);
                         return (ISC_R_IGNORE);
                 }
@@ -1231,8 +1231,8 @@ internal_current4(isc_interfaceiter_t *iter) {
                  */
                 if (isc_ioctl(iter->socket, SIOCGIFBRDADDR, (char *)&ifreq)
                     < 0) {
-                        strerror_r(errno, strbuf, sizeof(strbuf));
-                        UNEXPECTED_ERROR("%s: getting broadcast address: %s",
+                        ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                        msyslog(LOG_ERR, "%s: getting broadcast address: %s",
                                          ifreq.ifr_name, strbuf);
                         return (ISC_R_IGNORE);
                 }
@@ -1251,8 +1251,8 @@ internal_current4(isc_interfaceiter_t *iter) {
          * and is really hard to shut up.
          */
         if (isc_ioctl(iter->socket, SIOCGIFNETMASK, (char *)&ifreq) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("%s: getting netmask: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "%s: getting netmask: %s",
                                  ifreq.ifr_name, strbuf);
                 return (ISC_R_IGNORE);
         }
@@ -1331,8 +1331,8 @@ internal_current6(isc_interfaceiter_t *iter) {
          * and is really hard to shut up.
          */
         if (isc_ioctl(fd, SIOCGLIFFLAGS, (char *) &lifreq) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("%s: getting interface flags: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "%s: getting interface flags: %s",
                                  lifreq.lifr_name, strbuf);
                 return (ISC_R_IGNORE);
         }
@@ -1370,8 +1370,8 @@ internal_current6(isc_interfaceiter_t *iter) {
                  */
                 if (isc_ioctl(fd, SIOCGLIFDSTADDR, (char *)&lifreq)
                     < 0) {
-                        strerror_r(errno, strbuf, sizeof(strbuf));
-                        UNEXPECTED_ERROR("%s: getting destination address: %s",
+                        ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                        msyslog(LOG_ERR, "%s: getting destination address: %s",
                                          lifreq.lifr_name, strbuf);
                         return (ISC_R_IGNORE);
                 }
@@ -1390,8 +1390,8 @@ internal_current6(isc_interfaceiter_t *iter) {
                  */
                 if (isc_ioctl(iter->socket, SIOCGLIFBRDADDR, (char *)&lifreq)
                     < 0) {
-                        strerror_r(errno, strbuf, sizeof(strbuf));
-                        UNEXPECTED_ERROR("%s: getting broadcast address: %s",
+                        ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                        msyslog(LOG_ERR, "%s: getting broadcast address: %s",
                                          lifreq.lifr_name, strbuf);
                         return (ISC_R_IGNORE);
                 }
@@ -1434,8 +1434,8 @@ internal_current6(isc_interfaceiter_t *iter) {
          * and is really hard to shut up.
          */
         if (isc_ioctl(fd, SIOCGLIFNETMASK, (char *)&lifreq) < 0) {
-                strerror_r(errno, strbuf, sizeof(strbuf));
-                UNEXPECTED_ERROR("%s: getting netmask: %s",
+                ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+                msyslog(LOG_ERR, "%s: getting netmask: %s",
                                  lifreq.lifr_name, strbuf);
                 return (ISC_R_IGNORE);
         }
