@@ -10,10 +10,6 @@
 #include <stdio.h>
 #include <sys/types.h>
 
-#if defined(HAVE_SYS_SYSCTL_H)
-#include <sys/sysctl.h>
-#endif
-
 /* hack to ignore GCC Unused Result */
 #define IGNORE(r) do{if(r){}}while(0)
 
@@ -26,7 +22,7 @@
 #include <netinet/in.h>                /* Contractual promise. */
 
 #include "isc_netaddr.h"
-#include "isc_error.h"
+#include "ntp_stdlib.h"
 #include "isc_result.h"
 
 static isc_result_t	ipv4_result = ISC_R_NOTFOUND;
@@ -53,8 +49,8 @@ try_proto(int domain) {
 #endif
 			return (ISC_R_NOTFOUND);
 		default:
-			IGNORE(strerror_r(errno, strbuf, sizeof(strbuf)));
-			UNEXPECTED_ERROR("socket() failed: %s", strbuf);
+			ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+			msyslog(LOG_ERR, "socket() failed: %s", strbuf);
 			return (ISC_R_UNEXPECTED);
 		}
 	}
@@ -156,8 +152,8 @@ initialize_ipv6only(void) {
 	/* check for TCP sockets */
 	s = socket(PF_INET6, SOCK_STREAM, 0);
 	if (s == -1) {
-		IGNORE(strerror_r(errno, strbuf, sizeof(strbuf)));
-		UNEXPECTED_ERROR("socket() failed: %s", strbuf);
+		ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+		msyslog(LOG_ERR, "socket() failed: %s", strbuf);
 		ipv6only_result = ISC_R_UNEXPECTED;
 		return;
 	}
@@ -173,8 +169,8 @@ initialize_ipv6only(void) {
 	/* check for UDP sockets */
 	s = socket(PF_INET6, SOCK_DGRAM, 0);
 	if (s == -1) {
-	    IGNORE(strerror_r(errno, strbuf, sizeof(strbuf)));
-		UNEXPECTED_ERROR("socket() failed: %s", strbuf);
+		ntp_strerror_r(errno, strbuf, sizeof(strbuf));
+		msyslog(LOG_ERR, "socket() failed: %s", strbuf);
 		ipv6only_result = ISC_R_UNEXPECTED;
 		return;
 	}
