@@ -10,18 +10,14 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <string.h>
 
 #include "ntp.h"
 #include "ntp_debug.h"
+#include "ntp_stdlib.h"
 #include "ntp_syslog.h"
 #include "lib_strbuf.h"
 
-/* Use XSI-compliant strerror_r(3), prototype in string.h.
- * Don't try moving this further up, else hilarity will ensue...
- */
-#undef _GNU_SOURCE
-#include <string.h>
-
 /* start out with syslog and stderr, otherwise startup errors lost */
 bool    syslogit = true;        /* log messages to syslog */
 bool    termlogit = true;       /* duplicate to stdout/err */
@@ -329,7 +325,7 @@ change_logfile(
 				 log_fname);
 		} else
 			abs_fname = estrdup(log_fname);
-		TPRINT(1, ("attempting to open log %s\n", abs_fname));
+		DPRINT(1, ("attempting to open log %s\n", abs_fname));
 		new_file = fopen(abs_fname, "a");
 	}
 
@@ -448,7 +444,7 @@ reopen_logfile(void)
 }
 
 /* Hack because there are 2 APIs to strerror_r()  */
-void mystrerror(int errnum, char *buf, size_t buflen) {
+void ntp_strerror_r(int errnum, char *buf, size_t buflen) {
 #ifdef STRERROR_CHAR
 	char *answer = strerror_r(errnum, buf, buflen);
 	if (answer != buf) {
