@@ -9,6 +9,7 @@
 #include "ntp_stdlib.h"
 
 #include <stdbool.h>
+#include <openssl/ssl.h>
 #include <openssl/evp.h>
 #include <openssl/cmac.h>
 
@@ -29,10 +30,12 @@ CMAC_CTX *cmac_ctx;
 void
 ssl_init(void)
 {
-	if (ssl_init_done)
+	if (ssl_init_done) {
 		return;
+}
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
+	SSL_library_init();
 	OpenSSL_add_all_digests();
 	OpenSSL_add_all_ciphers();
 	atexit(&atexit_ssl_cleanup);
