@@ -4,10 +4,25 @@
 ntpdig - simple SNTP client
 
 """
-# SPDX-License-Identifier: BSD-2-clause
+# SPDX-License-Identifier: BSD-2-Clause
 # This code runs identically under Python 2 and Python 3. Keep it that way!
 from __future__ import print_function, division
+import getopt
+import math
+import select
+import socket
+import sys
+import time
 
+try:
+    import ntp.magic
+    import ntp.packet
+    import ntp.util
+except ImportError as e:
+    sys.stderr.write(
+        "ntpdig: can't find Python NTP library -- check PYTHONPATH.\n")
+    sys.stderr.write("%s\n" % e)
+    sys.exit(1)
 # This code is somewhat stripped down from the legacy C version.  It
 # does however have one additional major feature; it can filter
 # out falsetickers from multiple samples, like the ntpdate of old,
@@ -39,23 +54,6 @@ from __future__ import print_function, division
 #
 # The one new option in this version is -p, borrowed from ntpdate.
 
-import sys
-import socket
-import select
-import time
-import getopt
-import math
-
-try:
-    import ntp.magic
-    import ntp.packet
-    import ntp.util
-except ImportError as e:
-    sys.stderr.write(
-        "ntpdig: can't find Python NTP library -- check PYTHONPATH.\n")
-    sys.stderr.write("%s\n" % e)
-    sys.exit(1)
-
 
 def read_append(s, packets, packet, sockaddr):
     d, a = s.recvfrom(1024)
@@ -233,6 +231,7 @@ def report(packet, json):
             say(" " + packet.resolved)
         say(" s%d %s\n" % (packet.stratum, packet.leap()))
 
+
 usage = """
 USAGE:  ntpdig [-<flag> [<val>] | --<name>[{=| }<val>]]...
                 [ hostname-or-IP ...]
@@ -261,7 +260,13 @@ USAGE:  ntpdig [-<flag> [<val>] | --<name>[{=| }<val>]]...
    -h no  help            Display extended usage information and exit
 """
 
+
 if __name__ == '__main__':
+    bin_ver = "ntpsec-@NTPSEC_VERSION_EXTENDED@"
+    if ntp.util.stdversion() != bin_ver:
+        sys.stderr.write("Module/Binary version mismatch\n")
+        sys.stderr.write("Binary: %s\n" % bin_ver)
+        sys.stderr.write("Module: %s\n" % ntp.util.stdversion())
     try:
         try:
             (options, arguments) = getopt.getopt(
@@ -349,7 +354,7 @@ if __name__ == '__main__':
                     print(usage)
                     raise SystemExit(0)
                 elif switch in ("-V", "--version"):
-                    print("ntpdig %s" % ntp.util.stdversion())
+                    print("ntpdig %s" % bin_ver)
                     raise SystemExit(0)
                 else:
                     sys.stderr.write(
@@ -367,7 +372,8 @@ if __name__ == '__main__':
         try:
             credentials = ntp.packet.Authenticator(keyfile)
         except (OSError, IOError):
-            sys.stderr.write("ntpdig: %s nonexistent or unreadable\n" % keyfile)
+            sys.stderr.write("ntpdig: %s nonexistent or unreadable\n" %
+                             keyfile)
             raise SystemExit(1)
         if credentials:
             try:
@@ -396,7 +402,7 @@ if __name__ == '__main__':
             for s in range(samples):
                 if needgap and not firstloop:
                     time.sleep(gap)
-                if firstloop is True:
+                if firstloop:
                     firstloop = False
                 for server in concurrent_hosts:
                     try:
