@@ -1893,31 +1893,21 @@ config_rlimit(
 			break;
 
 		case T_Memlock:
-			/* ignore, for backward compatibility */
+			msyslog(LOG_WARNING, "CONFIG: memlock ignored");
 			break;
 
 		case T_Stacksize:
-#if defined(RLIMIT_STACK)
 			ntp_rlimit(RLIMIT_STACK,
 				   (rlim_t)(rlimit_av->value.i * 4096),
 				   4096,
 				   "4k");
-#else
-			/* STDERR as well would be fine... */
-			msyslog(LOG_WARNING, "CONFIG: 'rlimit stacksize' specified but is not available on this system.");
-#endif /* RLIMIT_STACK */
 			break;
 
 		case T_Filenum:
-#if defined(RLIMIT_NOFILE)
 			ntp_rlimit(RLIMIT_NOFILE,
 				  (rlim_t)(rlimit_av->value.i),
 				  1,
 				  "");
-#else
-			/* STDERR as well would be fine... */
-			msyslog(LOG_WARNING, "CONFIG: 'rlimit filenum' specified but is not available on this system.");
-#endif /* RLIMIT_NOFILE */
 			break;
 
 		}
@@ -3166,7 +3156,7 @@ void readconfig(const char *config_file)
 	/* parse configs in parallel subdirectory if that exists */
 	reparent(dirpath, sizeof(dirpath), config_file, CONFIG_DIR);
 	if (is_directory(dirpath) && lex_push_file(dirpath)) {
-		msyslog(LOG_INFO, "CONFIG: readconfig: parsing directory: %s", config_file);
+		msyslog(LOG_INFO, "CONFIG: readconfig: parsing directory: %s", dirpath);
 	    yyparse();
 	    ++srccount;
 	}
@@ -3632,13 +3622,7 @@ ntp_rlimit(
 #endif
 
 	switch (rl_what) {
-#ifdef RLIMIT_MEMLOCK
-	    case RLIMIT_MEMLOCK:
-		/* ignore - for backward compatibility only */
-		break;
-#endif /* RLIMIT_MEMLOCK */
 
-#ifdef RLIMIT_NOFILE
 	    case RLIMIT_NOFILE:
 		/*
 		 * For large systems the default file descriptor limit may
@@ -3650,9 +3634,7 @@ ntp_rlimit(
 		if (setrlimit(RLIMIT_NOFILE, &rl) == -1)
 			msyslog(LOG_ERR, "CONFIG: Cannot set RLIMIT_NOFILE: %s", strerror(errno));
 		break;
-#endif /* RLIMIT_NOFILE */
 
-#ifdef RLIMIT_STACK
 	    case RLIMIT_STACK:
 		/*
 		 * Provide a way to set the stack limit to something
@@ -3678,7 +3660,6 @@ ntp_rlimit(
 			}
 		}
 		break;
-#endif /* RLIMIT_STACK */
 
 	    default:
 		INSIST(!"Unexpected setrlimit() case!");
