@@ -41,7 +41,8 @@ int interface_interval;     /* init_io() sets def. 300s */
  */
 static uptime_t interface_timer;	/* interface update timer */
 static uptime_t adjust_timer;	/* second timer */
-static uptime_t stats_timer;	/* stats timer */
+static uptime_t stats_timer;
+static uptime_t cookie_timer;
 static uptime_t leapf_timer;	/* Report leapfile problems once/day */
 static uptime_t huffpuff_timer;	/* huff-n'-puff timer */
 static unsigned long	leapsec; /* secs to next leap (proximity class) */
@@ -95,8 +96,8 @@ set_timer_or_die(
 	rc = setitimer(ITIMER_REAL, &itimer, NULL);
 #endif
 	if (-1 == rc) {
-		msyslog(LOG_ERR, "ERR:interval timer %s failed, %m",
-			setfunc);
+		msyslog(LOG_ERR, "ERR:interval timer %s failed, %s",
+			setfunc, strerror(errno));
 		exit(1);
 	}
 }
@@ -141,6 +142,7 @@ init_timer(void)
 	alarm_overflow = 0;
 	adjust_timer = 1;
 	stats_timer = SECSPERHR;
+	cookie_timer = SECSPERHR;
 	leapf_timer = SECSPERDAY;
 	huffpuff_timer = 0;
 	interface_timer = 0;
@@ -155,7 +157,7 @@ init_timer(void)
 	 */
 #ifdef HAVE_TIMER_CREATE
 	if (TC_ERR == timer_create(CLOCK_REALTIME, NULL, &timer_id)) {
-		msyslog(LOG_ERR, "ERR: timer_create failed, %m");
+		msyslog(LOG_ERR, "ERR: timer_create failed, %s", strerror(errno));
 		exit(1);
 	}
 #endif
@@ -238,7 +240,7 @@ timer(void)
 			sys_vars.sys_refid = htonl(LOOPBACKADR);
 		else
 			memcpy(&sys_vars.sys_refid, "LOOP", REFIDLEN);
-		sys_offset = 0;
+		clkstate.sys_offset = 0;
 		sys_vars.sys_rootdelay = 0;
 		sys_vars.sys_rootdisp = 0;
 	}
@@ -293,6 +295,12 @@ timer(void)
 			check_leap_file(false, now);
 		}
 	}
+
+	/* time for new NTS K/I ? */
+	if (cookie_timer <= current_time) {
+		cookie_timer += 5*60;
+		nts_timer();
+	}
 }
 
 
@@ -451,16 +459,16 @@ check_leapsec(
 	  	if (fired) {
 			const char *leapmsg = NULL;
 			if (lsdata.warped < 0) {
-				if (clock_max_back > 0.0 &&
-				    clock_max_back < abs(lsdata.warped)) {
+				if (loop_data.clock_max_back > 0.0 &&
+				    loop_data.clock_max_back < abs(lsdata.warped)) {
 					step_systime(lsdata.warped, ntp_set_tod);
 					leapmsg = leapmsg_p_step;
 				} else {
 					leapmsg = leapmsg_p_slew;
 				}
 			} else 	if (lsdata.warped > 0) {
-				if (clock_max_fwd > 0.0 &&
-				    clock_max_fwd < abs(lsdata.warped)) {
+				if (loop_data.clock_max_fwd > 0.0 &&
+				    loop_data.clock_max_fwd < abs(lsdata.warped)) {
 					step_systime(lsdata.warped, ntp_set_tod);
 					leapmsg = leapmsg_n_step;
 				} else {
@@ -506,10 +514,11 @@ check_leapsec(
 		leapsec = lsprox;
 	}
 
-	if (leapsec >= LSPROX_SCHEDULE)
+	if (leapsec >= LSPROX_SCHEDULE) {
 		leapdif = lsdata.tai_diff;
-	else
+	} else {
 		leapdif = 0;
+	}
 
 	check_leap_sec_in_progress(&lsdata);
 }
