@@ -14,7 +14,6 @@
 #include "ntp_assert.h"
 #include "ntp_auth.h"
 #include "ntp_dns.h"
-#include "isc_error.h"
 
 #include <unistd.h>
 #include <sys/stat.h>
@@ -802,13 +801,15 @@ ntpdmain(
 	 * Need to do this before droproot.
 	 */
 	{
+#ifdef RLIMIT_MEMLOCK
+	    /* RLIMIT_MEMLOCK is Linux/BSD, not POSIX */
 	    struct rlimit rlim;
 	    rlim.rlim_max = rlim.rlim_cur = RLIM_INFINITY;
-#ifdef RLIMIT_MEMLOCK
 	    if (setrlimit(RLIMIT_MEMLOCK, &rlim) < 0)
 		msyslog(LOG_WARNING, "INIT: setrlimit() failed: not locking into RAM");
 	    else
 #endif
+
 	    if (mlockall(MCL_CURRENT|MCL_FUTURE) < 0)
 		msyslog(LOG_WARNING, "INIT: mlockall() failed: not locking into RAM");
 	    else
