@@ -29,6 +29,7 @@
 #include "nts.h"
 #include "nts2.h"
 #include "ntp_dns.h"
+#include "ntp_stdlib.h"
 
 SSL_CTX* make_ssl_client_ctx(const char *filename);
 int open_TCP_socket(struct peer *peer, const char *hostname);
@@ -40,20 +41,22 @@ bool nts_client_send_request(SSL *ssl, struct peer *peer);
 bool nts_client_process_response(SSL *ssl, struct peer *peer);
 bool nts_client_process_response_core(uint8_t *buff, int transferred, struct peer* peer);
 bool nts_client_send_request_core(uint8_t *buff, int buf_size, int *used, struct peer* peer);
-bool nts_server_lookup(char *server, sockaddr_u *addr);
+bool nts_server_lookup(char *server, sockaddr_u *addr, int af);
 
 static SSL_CTX *client_ctx = NULL;
 static sockaddr_u sockaddr;
 static bool addrOK;
 
+// Fedora 30:  0x1010104fL  1.1.1d
 // Fedora 29:  0x1010102fL  1.1.1b
 // Fedora 28:  0x1010009fL  1.1.0i
+// Debian 10:  0x1010104fL  1.1.1d
 // Debian 9:   0x101000afL  1.1.0j
 // Debian 8:   0x1000114fL  1.0.1t
 // CentOS 7:   0x100020bfL  1.0.2k
 // CentOS 6:   0x1000105fL  1.0.1e
 // NetBSD 8:   0x100020bfL  1.0.2k
-// NetBSD 7:   0x1000115fL  1.0.1u
+// NetBSD 7:   0x1000115fL  1.0.1u (1.0.2s via pkgin)
 // FreeBSD 12: 0x1010101fL  1.1.1a-freebsd
 // FreeBSD 11: 0x100020ffL  1.0.2o-freebsd
 
@@ -104,7 +107,7 @@ bool nts_probe(struct peer * peer) {
 
 	err = setsockopt(server, SOL_SOCKET, SO_RCVTIMEO, &timeout, sizeof(timeout));
 	if (0 > err) {
-		mystrerror(errno, errbuf, sizeof(errbuf));
+		ntp_strerror_r(errno, errbuf, sizeof(errbuf));
 		msyslog(LOG_ERR, "NTSc: can't setsockopt: %s", errbuf);
 		close(server);
 		nts_ke_probes_bad++;
@@ -116,6 +119,10 @@ bool nts_probe(struct peer * peer) {
 	else {
 		SSL_CTX *ctx; 
 		ctx = make_ssl_client_ctx(peer->cfg.nts_cfg.ca);
+		if (NULL == ctx) {
+			close(server);
+			return false;
+		}
 		ssl = SSL_new(ctx);
 		SSL_CTX_free(ctx);
 	}
@@ -212,7 +219,7 @@ SSL_CTX* make_ssl_client_ctx(const char * filename) {
 		/* Happens if no ciphers */
 		msyslog(LOG_ERR, "NTSc: NULL ctx");
 		nts_log_ssl_error();
-		exit(1);
+		return NULL;
 	}
 
 #if (OPENSSL_VERSION_NUMBER > 0x1000200fL)
@@ -232,7 +239,8 @@ SSL_CTX* make_ssl_client_ctx(const char * filename) {
 
 	if (!ok) {
 		msyslog(LOG_ERR, "NTSc: Troubles setting up client SSL CTX");
-		exit(1);
+		SSL_CTX_free(ctx);
+		return NULL;
 	};
 
 	return ctx;
@@ -295,13 +303,13 @@ int open_TCP_socket(struct peer *peer, const char *hostname) {
 
 	sockfd = socket(answer->ai_family, SOCK_STREAM, 0);
 	if (-1 == sockfd) {
-		mystrerror(errno, errbuf, sizeof(errbuf));
+		ntp_strerror_r(errno, errbuf, sizeof(errbuf));
 		msyslog(LOG_INFO, "NTSc: nts_probe: no socket: %s", errbuf);
 	} else {
 		// Use first answer
 		err = connect(sockfd, answer->ai_addr, answer->ai_addrlen);
 		if (-1 == err) {
-			mystrerror(errno, errbuf, sizeof(errbuf));
+			ntp_strerror_r(errno, errbuf, sizeof(errbuf));
 			msyslog(LOG_INFO, "NTSc: nts_probe: connect failed: %s", errbuf);
 			close(sockfd);
 			sockfd = -1;
@@ -328,17 +336,20 @@ void set_hostname(SSL *ssl, const char *hostname) {
 
 // https://wiki.openssl.org/index.php/Hostname_validation
 #if (OPENSSL_VERSION_NUMBER > 0x1010000fL)
+	SSL_set_hostflags(ssl, X509_CHECK_FLAG_NO_WILDCARDS);
 	SSL_set1_host(ssl, host);
 	msyslog(LOG_DEBUG, "NTSc: set cert host: %s", host);
 #elif (OPENSSL_VERSION_NUMBER > 0x1000200fL)
-	{
-		X509_VERIFY_PARAM *param = SSL_get0_param(ssl);
-		if (1 != X509_VERIFY_PARAM_set1_host(param, host, strlen(host))) {
-			msyslog(LOG_ERR, "NTSc: troubles setting hostflags");
-		}
-		SSL_set_verify(ssl, SSL_VERIFY_PEER, NULL);
+	{  /* enable automatic hostname checks */
+	X509_VERIFY_PARAM *param = SSL_get0_param(ssl);
+	X509_VERIFY_PARAM_set_hostflags(param, X509_CHECK_FLAG_NO_WILDCARDS);
+	if (1 != X509_VERIFY_PARAM_set1_host(param, host, strlen(host))) {
+		msyslog(LOG_ERR, "NTSc: troubles setting hostflags");
+	}
+	SSL_set_verify(ssl, SSL_VERIFY_PEER, NULL);
 	}
 #else
+	/*  Versions prior to 1.0.2 did not perform hostname validation */
 	UNUSED_ARG(ssl);
 	msyslog(LOG_ERR, "NTSc: can't check hostname/certificate");
 #endif
@@ -374,9 +385,6 @@ bool check_certificate(SSL *ssl, struct peer* peer) {
 				return false;
 		}
 	}
-#if (OPENSSL_VERSION_NUMBER > 0x1010000fL)
-	msyslog(LOG_DEBUG, "NTSc: matched cert host: %s", SSL_get0_peername(ssl));
-#endif
 	return true;
 }
 
@@ -395,7 +403,14 @@ bool check_aead(SSL *ssl, struct peer* peer, const char *hostname) {
 			hostname, SSL_get_version(ssl));
 		return bad;
 	}
-	strlcpy(buff, (const char*)data, sizeof(buff));	/* NUL terminate */
+	if (sizeof(buff) <= len) {
+		/* Broken or malicious server */
+		msyslog(LOG_DEBUG, "NTSc: Very long ALPN from %s (%u)",
+			hostname, len);
+		return bad;
+	}
+	memcpy(buff, data, len);
+	buff[len] = '\0';
 	for (i=0; i<len; i++) {
 		if (!isgraph(buff[i])) {
 			buff[i] = '*'; /* fix non-printing crap */
@@ -404,7 +419,8 @@ bool check_aead(SSL *ssl, struct peer* peer, const char *hostname) {
 	/* For now, we only support one version.
 	 * This gets more complicated when version 2 arrives. */
 	if (0 != strcmp((const char*)data, "ntske/1")) {
-		msyslog(LOG_DEBUG, "NTSc: Strange ALPN returned: %s (%u)", buff, len);
+		msyslog(LOG_DEBUG, "NTSc: Strange ALPN returned: %s (%u) from %s",
+			buff, len, hostname);
 		return bad;
 	}
         msyslog(LOG_DEBUG, "NTSc: Good ALPN from: %s", hostname);
@@ -494,7 +510,7 @@ bool nts_client_send_request_core(uint8_t *buff, int buf_size, int *used, struct
 
 	*used = buf_size-buf.left;
 	if (*used >= (int)(buf_size - 10)) {
-		mystrerror(errno, errbuf, sizeof(errbuf));
+		ntp_strerror_r(errno, errbuf, sizeof(errbuf));
 		msyslog(LOG_ERR, "NTSc: write failed: %d, %ld, %s",
 			*used, (long)buf_size, errbuf);
 		return false;
@@ -592,14 +608,15 @@ bool nts_client_process_response_core(uint8_t *buff, int transferred, struct pee
 			peer->nts_state.count++;
 			break;
 		    case nts_server_negotiation:
-			if (MAX_SERVER < length) {
+			if (MAX_SERVER < (length+1)) {
 				msyslog(LOG_ERR, "NTSc: server string too long %d.", length);
 				return false;
 			}
 			next_bytes(&buf, (uint8_t *)server, length);
+			server[length] = '\0';
 			/* save port in case port specified before server */
 			port = SRCPORT(&sockaddr);
-			if (!nts_server_lookup(server, &sockaddr))
+			if (!nts_server_lookup(server, &sockaddr, AF(&peer->srcadr)))
 				return false;
 			SET_PORT(&sockaddr, port);
 			socktoa_r(&sockaddr, errbuf, sizeof(errbuf));
@@ -675,13 +692,17 @@ bool nts_set_cert_search(SSL_CTX *ctx, const char *filename) {
 			filename, statbuf.st_mode);
 		return false;
 	}
-	mystrerror(errno, errbuf, sizeof(errbuf));
+	ntp_strerror_r(errno, errbuf, sizeof(errbuf));
 	msyslog(LOG_ERR, "NTSc: can't stat cert dir/file: %s, %s",
-		ntsconfig.ca, errbuf);
+		filename, errbuf);
 	return false;
 }
-
-bool nts_server_lookup(char *server, sockaddr_u *addr) {
+/* The -4/-6 option is used for both the NTS-KE server and the NTP server.
+ * That will break if the KE server returns a name that returns only an
+ * address of the other type.
+ * We could fix that by trying again with AF_UNSPEC.
+ */
+bool nts_server_lookup(char *server, sockaddr_u *addr, int af) {
 	struct addrinfo hints;
 	struct addrinfo *answer;
 	int gai_rc;
@@ -689,11 +710,11 @@ bool nts_server_lookup(char *server, sockaddr_u *addr) {
 	ZERO(hints);
 	hints.ai_protocol = IPPROTO_UDP;
 	hints.ai_socktype = SOCK_DGRAM;
-	hints.ai_family = AF_UNSPEC;
+	hints.ai_family = af;
 
 	gai_rc = getaddrinfo(server, "123", &hints, &answer);
 	if (0 != gai_rc) {
-		msyslog(LOG_INFO, "NTSc: nts_probe: DNS error trying to lookup %s: %d, %s",
+		msyslog(LOG_INFO, "NTSc: DNS error trying to lookup %s: %d, %s",
 			server, gai_rc, gai_strerror(gai_rc));
 		return false;
 	}
