@@ -60,15 +60,10 @@
  */
 
 
-/* The strptime prototype is not provided unless explicitly requested.
- * See the POSIX spec for more info:
- * http://pubs.opengroup.org/onlinepubs/9699919799/functions/V2_chap02.html#tag_15_02_01_02
- */
-#define _XOPEN_SOURCE 600
-
 #include "config.h"
 #include "ntp.h"
 #include "ntp_types.h"
+#include "ntp_debug.h"
 
 /* =====================================================================
  * Get the little JSMN library directly into our guts. Use the 'parent
@@ -2163,6 +2158,12 @@ log_data(
 	const char *buf ,
 	size_t      len )
 {
+#ifndef DEBUG
+	UNUSED_ARG(peer);
+	UNUSED_ARG(what);
+	UNUSED_ARG(buf);
+	UNUSED_ARG(len);
+#else
 	char s_lbuf[MAX_PDU_LEN];
 
 	clockprocT * const pp = peer->procptr;
@@ -2192,5 +2193,6 @@ log_data(
 		*dptr = '\0';
 		printf("%s[%s]: '%s'\n", up->logname, what, s_lbuf);
 	}
+#endif
 }
 
