@@ -31,6 +31,7 @@
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
 #include "ntp_calendar.h"
+#include "ntp_wrapdate.h"
 #include "timespecops.h"
 
 #ifdef HAVE_PPSAPI
@@ -247,18 +248,6 @@ typedef struct {
 	int    cidx;	/* current field index	*/
 } nmea_data;
 
-/*
- * NMEA gps week/time information
- * This record contains the number of weeks since 1980-01-06 modulo
- * 1024, the seconds elapsed since start of the week, and the number of
- * leap seconds that are the difference between GPS and UTC time scale.
- */
-typedef struct {
-	uint32_t 	wt_time;	/* seconds since weekstart */
-	unsigned short	wt_week;	/* week number */
-	short		wt_leap;	/* leap seconds */
-} gps_weektm;
-
 /*
  * The GPS week time scale starts on Sunday, 1980-01-06. We need the
  * rata die number of this day.
@@ -296,13 +285,6 @@ static bool	parse_date	(struct calendar *jd, nmea_data*,
 				 int idx, enum date_fmt fmt);
 static bool	parse_weekdata	(gps_weektm *, nmea_data *,
 				 int weekidx, int timeidx, int leapidx);
-/* calendar / date helpers */
-static bool	unfold_day	(struct calendar * jd, uint32_t rec_ui);
-static bool	unfold_century	(struct calendar * jd, uint32_t rec_ui);
-static bool	gpsfix_century	(struct calendar * jd, const gps_weektm * wd,
-				 unsigned short * ccentury);
-static l_fp     eval_gps_time	(struct peer * peer, const struct calendar * gpst,
-				 const struct timespec * gpso, const l_fp * xrecv);
 
 static void     save_ltc        (struct refclockproc * const, const char * const,
 				 size_t);
@@ -315,9 +297,6 @@ static void     save_ltc        (struct refclockproc * const, const char * const
 static	void gps_send(int, const char *, struct peer *);
 #endif /* NMEA_WRITE_SUPPORT */
 
-static int32_t g_gpsMinBase;
-static int32_t g_gpsMinYear;
-
 /*
  * -------------------------------------------------------------------
  * Transfer vector
@@ -344,28 +323,7 @@ struct refclock refclock_nmea = {
 static void
 nmea_init(void)
 {
-	struct calendar date;
-
-	/* - calculate min. base value for GPS epoch & century unfolding
-	 * This assumes that the build system was roughly in sync with
-	 * the world, and that really synchronising to a time before the
-	 * program was created would be unsafe or insane. If the build
-	 * date cannot be stablished, at least use the start of GPS
-	 * (1980-01-06) as minimum, because GPS can surely NOT
-	 * synchronise beyond it's own big bang. We add a little safety
-	 * margin for the fuzziness of the build date, which is in an
-	 * undefined time zone. */
-	if (ntpcal_get_build_date(&date))
-		g_gpsMinBase = ntpcal_date_to_rd(&date) - 2;
-	else
-		g_gpsMinBase = 0;
-
-	if (g_gpsMinBase < DAY_GPS_STARTS)
-		g_gpsMinBase = DAY_GPS_STARTS;
-
-	ntpcal_rd_to_date(&date, g_gpsMinBase);
-	g_gpsMinYear  = date.year;
-	g_gpsMinBase -= DAY_NTP_STARTS;
+    wrapdate_init();
 }
 
 /*
@@ -478,8 +436,8 @@ nmea_start(
 		}
 		path = device;
         }
-	/* Open serial port. Use CLK line discipline, if available. */
-	pp->io.fd = refclock_open(path, baudrate, LDISC_CLK);
+	/* Open serial port. */
+	pp->io.fd = refclock_open(path, baudrate, LDISC_STD);
 
 	if (0 > pp->io.fd) {
 		msyslog(LOG_ERR, "REFCLOCK: %s NMEA device open(%s) failed",
@@ -867,20 +825,21 @@ nmea_receive(
 	 * start.
 	 */
 	cp = field_parse(&rdata, 0);
-	if      (strncmp(cp + 2, "RMC,", 4) == 0)
+	if      (strncmp(cp + 2, "RMC,", 4) == 0) {
 		sentence = NMEA_GPRMC;
-	else if (strncmp(cp + 2, "GGA,", 4) == 0)
+	} else if (strncmp(cp + 2, "GGA,", 4) == 0) {
 		sentence = NMEA_GPGGA;
-	else if (strncmp(cp + 2, "GLL,", 4) == 0)
+	} else if (strncmp(cp + 2, "GLL,", 4) == 0) {
 		sentence = NMEA_GPGLL;
-	else if (strncmp(cp + 2, "ZDA,", 4) == 0)
+	} else if (strncmp(cp + 2, "ZDA,", 4) == 0) {
 		sentence = NMEA_GPZDA;
-	else if (strncmp(cp + 2, "ZDG,", 4) == 0)
+	} else if (strncmp(cp + 2, "ZDG,", 4) == 0) {
 		sentence = NMEA_GPZDG;
-	else if (strncmp(cp,   "PGRMF,", 6) == 0)
+	} else if (strncmp(cp,   "PGRMF,", 6) == 0) {
 		sentence = NMEA_PGRMF;
-	else
+	} else {
 		return;	/* not something we know about */
+	}
 
 	/* Eventually output delay measurement now. */
 	if (peer->cfg.mode & NMEA_DELAYMEAS_MASK) {
@@ -1049,7 +1008,8 @@ nmea_receive(
 	 * timecode timestamp, but only if the PPS is not in control.
 	 * Discard sentence if reference time did not change.
 	 */
-	rd_reftime = eval_gps_time(peer, &date, &tofs, &rd_timestamp);
+	rd_reftime = eval_gps_time(refclock_name(peer), &date, &tofs, 
+				   (peer->cfg.mode & NMEA_DATETRUST_MASK), &up->epoch_warp, &rd_timestamp);
 	if (up->last_reftime == rd_reftime) {
 		/* Do not touch pp->a_lastcode on purpose! */
 		up->tally.filtered++;
@@ -1179,7 +1139,9 @@ nmea_poll(
 	if (peer->cfg.mode & NMEA_EXTLOG_MASK) {
 		/* Log & reset counters with extended logging */
 		const char *nmea = pp->a_lastcode;
-		if (*nmea == '\0') nmea = "(none)";
+		if (*nmea == '\0') {
+			nmea = "(none)";
+		}
 		mprintf_clock_stats(
 		  peer, "%s  %u %u %u %u %u %u",
 		  nmea,
@@ -1204,8 +1166,9 @@ save_ltc(
 	size_t                      len
 	)
 {
-	if (len >= sizeof(pp->a_lastcode))
+	if (len >= sizeof(pp->a_lastcode)) {
 		len = sizeof(pp->a_lastcode) - 1;
+	}
 	pp->lencode = (unsigned short)len;
 	memcpy(pp->a_lastcode, tc, len);
 	pp->a_lastcode[len] = '\0';
@@ -1321,8 +1284,9 @@ field_init(
 	cs_l = 0;
 	cs_r = 0;
 	/* some basic input constraints */
-	if (dlen < 0)
+	if (dlen < 0) {
 		dlen = 0;
+	}
 	eptr = cptr + dlen;
 	*eptr = '\0';
 
@@ -1339,10 +1303,12 @@ field_init(
 	 */
 
 	/* -*- start character: '^\$' */
-	if (*cptr == '\0')
+	if (*cptr == '\0') {
 		return CHECK_EMPTY;
-	if (*cptr++ != '$')
+	}
+	if (*cptr++ != '$') {
 		return CHECK_INVALID;
+	}
 
 	/* -*- advance context beyond start character */
 	data->base++;
@@ -1350,14 +1316,16 @@ field_init(
 	data->blen--;
 
 	/* -*- field name: '[A-Z][A-Z0-9]{4,},' */
-	if (*cptr < 'A' || *cptr > 'Z')
+	if (*cptr < 'A' || *cptr > 'Z') {
 		return CHECK_INVALID;
+	}
 	cs_l ^= *cptr++;
 	while ((*cptr >= 'A' && *cptr <= 'Z') ||
 	       (*cptr >= '0' && *cptr <= '9')  )
 		cs_l ^= *cptr++;
-	if (*cptr != ',' || (cptr - data->base) < NMEA_PROTO_IDLEN)
+	if (*cptr != ',' || (cptr - data->base) < NMEA_PROTO_IDLEN) {
 		return CHECK_INVALID;
+}
 	cs_l ^= *cptr++;
 
 	/* -*- data: '[^*]*' */
@@ -1365,19 +1333,22 @@ field_init(
 		cs_l ^= *cptr++;
 
 	/* -*- checksum field: (\*[0-9A-F]{2})?$ */
-	if (*cptr == '\0')
+	if (*cptr == '\0') {
 		return CHECK_VALID;
+}
 	if (*cptr != '*' || cptr != eptr - 3 ||
-	    (cptr - data->base) >= NMEA_PROTO_MAXLEN)
+	    (cptr - data->base) >= NMEA_PROTO_MAXLEN) {
 		return CHECK_INVALID;
+}
 
 	for (cptr++; (tmp = *cptr) != '\0'; cptr++) {
-		if (tmp >= '0' && tmp <= '9')
+		if (tmp >= '0' && tmp <= '9') {
 			cs_r = (cs_r << 4) + (tmp - '0');
-		else if (tmp >= 'A' && tmp <= 'F')
+		} else if (tmp >= 'A' && tmp <= 'F') {
 			cs_r = (cs_r << 4) + (tmp - 'A' + 10);
-		else
+		} else {
 			break;
+}
 	}
 
 	/* -*- make sure we are at end of string and csum matches */
@@ -1455,12 +1426,15 @@ field_wipe(
 			cp = field_parse(data, fidx);
 		} else {
 			cp = data->base + data->blen;
-			if (data->blen >= 3 && cp[-3] == '*')
+			if (data->blen >= 3 && cp[-3] == '*') {
 				cp -= 2;
+			}
 		}
-		for ( ; '\0' != *cp && '*' != *cp && ',' != *cp; cp++)
-			if ('.' != *cp)
+		for ( ; '\0' != *cp && '*' != *cp && ',' != *cp; cp++) {
+			if ('.' != *cp) {
 				*cp = '_';
+			}
+		}
 	} while (fcnt-- && fidx >= 0);
 	va_end(va);
 }
@@ -1541,10 +1515,11 @@ parse_time(
 	jd->minute = (uint8_t)m;
 	jd->second = (uint8_t)s;
 	/* if we have a fraction, scale it up to nanoseconds. */
-	if (rc == 4)
+	if (rc == 4) {
 		*ns = (long)(f * weight[p2 - p1 - 1]);
-	else
+	} else {
 		*ns = 0;
+}
 
 	return true;
 }
@@ -1649,259 +1624,4 @@ parse_weekdata(
 	return true;
 }
 
-/*
- * -------------------------------------------------------------------
- * funny calendar-oriented stuff -- perhaps a bit hard to grok.
- * -------------------------------------------------------------------
- *
- * Unfold a time-of-day (seconds since midnight) around the current
- * system time in a manner that guarantees an absolute difference of
- * less than 12hrs.
- *
- * This function is used for NMEA sentences that contain no date
- * information. This requires the system clock to be in +/-12hrs
- * around the true time, or the clock will synchronize the system 1day
- * off if not augmented with a time sources that also provide the
- * necessary date information.
- *
- * The function updates the calendar structure it also uses as
- * input to fetch the time from.
- *
- * returns true on success, false on failure
- * -------------------------------------------------------------------
- */
-static bool
-unfold_day(
-	struct calendar * jd,
-	uint32_t		  rec_ui
-	)
-{
-	time64_t	     rec_qw;
-	ntpcal_split rec_ds;
-
-	/*
-	 * basically this is the peridiodic extension of the receive
-	 * time - 12hrs to the time-of-day with a period of 1 day.
-	 * But we would have to execute this in 64bit arithmetic, and we
-	 * cannot assume we can do this; therefore this is done
-	 * in split representation.
-	 */
-	rec_qw = ntpcal_ntp_to_ntp(rec_ui - SECSPERDAY/2, time(NULL));
-	rec_ds = ntpcal_daysplit(rec_qw);
-	rec_ds.lo = ntpcal_periodic_extend(rec_ds.lo,
-					   ntpcal_date_to_daysec(jd),
-					   SECSPERDAY);
-	rec_ds.hi += ntpcal_daysec_to_date(jd, rec_ds.lo);
-	/* -1 return means calculation overflowed */
-	return (ntpcal_rd_to_date(jd, rec_ds.hi + DAY_NTP_STARTS) >= 0);
-}
-
-/*
- * -------------------------------------------------------------------
- * A 2-digit year is expanded into full year spec around the year found
- * in 'jd->year'. This should be in +79/-19 years around the system time,
- * or the result will be off by 100 years.  The asymmetric behaviour was
- * chosen to enable initial sync for systems that do not have a
- * battery-backup clock and start with a date that is typically years in
- * the past.
- *
- * Since the GPS epoch starts at 1980-01-06, the resulting year will be
- * not be before 1980 in any case.
- *
- * returns true on success, false on failure
- * -------------------------------------------------------------------
- */
-static bool
-unfold_century(
-	struct calendar * jd,
-	uint32_t		  rec_ui
-	)
-{
-	struct calendar rec;
-	int32_t		baseyear;
-
-	ntpcal_ntp_to_date(&rec, rec_ui, time(NULL));
-	baseyear = rec.year - 20;
-	if (baseyear < g_gpsMinYear)
-		baseyear = g_gpsMinYear;
-	jd->year = (unsigned short)ntpcal_periodic_extend(baseyear, jd->year,
-						   100);
-
-	return ((baseyear <= jd->year) && (baseyear + 100 > jd->year));
-}
-
-/*
- * -------------------------------------------------------------------
- * A 2-digit year is expanded into a full year spec by correlation with
- * a GPS week number and the current leap second count.
- *
- * The GPS week time scale counts weeks since Sunday, 1980-01-06, modulo
- * 1024 and seconds since start of the week. The GPS time scale is based
- * on international atomic time (TAI), so the leap second difference to
- * UTC is also needed for a proper conversion.
- *
- * A brute-force analysis (that is, test for every date) shows that a
- * wrong assignment of the century can not happen between the years 1900
- * to 2399 when comparing the week signatures for different
- * centuries. (I *think* that will not happen for 400*1024 years, but I
- * have no valid proof. -*-perlinger@ntp.org-*-)
- *
- * This function is bound to to work between years 1980 and 2399
- * (inclusive), which should suffice for now ;-)
- *
- * Note: This function needs a full date&time spec on input due to the
- * necessary leap second corrections!
- *
- * returns true on success, false on failure
- * -------------------------------------------------------------------
- */
-static bool
-gpsfix_century(
-	struct calendar  * jd,
-	const gps_weektm * wd,
-	unsigned short   * century
-	)
-{
-	int32_t	days;
-	int32_t	doff;
-	unsigned short week;
-	unsigned short year;
-	int     loop;
-
-	/* Get day offset. Assumes that the input time is in range and
-	 * that the leap seconds do not shift more than +/-1 day.
-	 */
-	doff = ntpcal_date_to_daysec(jd) + wd->wt_leap;
-	doff = (doff >= SECSPERDAY) - (doff < 0);
-
-	/*
-	 * Loop over centuries to get a match, starting with the last
-	 * successful one. (Or with the 19th century if the cached value
-	 * is out of range...)
-	 */
-	year = jd->year % 100;
-	for (loop = 5; loop > 0; loop--,(*century)++) {
-		if (*century < 19 || *century >= 24)
-			*century = 19;
-		/* Get days and week in GPS epoch */
-		jd->year = year + *century * 100;
-		days = ntpcal_date_to_rd(jd) - DAY_GPS_STARTS + doff;
-		week = (days / 7) % 1024;
-		if (days >= 0 && wd->wt_week == week)
-			return true; /* matched... */
-	}
-
-	jd->year = year;
-	return false; /* match failed... */
-}
-
-/*
- * -------------------------------------------------------------------
- * And now the final execise: Considering the fact that many (most?)
- * GPS receivers cannot handle a GPS epoch wrap well, we try to
- * compensate for that problem by unwrapping a GPS epoch around the
- * receive stamp. Another execise in periodic unfolding, of course,
- * but with enough points to take care of.
- *
- * Note: The integral part of 'tofs' is intended to handle small(!)
- * systematic offsets, as -1 for handling $GPZDG, which gives the
- * following second. (sigh...) The absolute value shall be less than a
- * day (86400 seconds).
- * -------------------------------------------------------------------
- */
-static l_fp
-eval_gps_time(
-	struct peer           * peer, /* for logging etc */
-	const struct calendar * gpst, /* GPS time stamp  */
-	const struct timespec * tofs, /* GPS frac second & offset */
-	const l_fp            * xrecv /* receive time stamp */
-	)
-{
-	struct refclockproc * const pp = peer->procptr;
-	nmea_unit	    * const up = (nmea_unit *)pp->unitptr;
-
-	l_fp    retv;
-
-	/* components of calculation */
-	int32_t rcv_sec, rcv_day; /* receive ToD and day */
-	int32_t gps_sec, gps_day; /* GPS ToD and day in NTP epoch */
-	int32_t adj_day, weeks;   /* adjusted GPS day and week shift */
-
-	/* some temporaries to shuffle data */
-	time64_t       vi64;
-	ntpcal_split rs64;
-
-	/* evaluate time stamp from receiver. */
-	gps_sec = ntpcal_date_to_daysec(gpst);
-	gps_day = ntpcal_date_to_rd(gpst) - DAY_NTP_STARTS;
-
-	/* merge in fractional offset */
-	retv = tspec_intv_to_lfp(*tofs);
-	gps_sec += lfpsint(retv);
-
-	/* If we fully trust the GPS receiver, just combine days and
-	 * seconds and be done. */
-	if (peer->cfg.mode & NMEA_DATETRUST_MASK) {
-		setlfpuint(retv, time64lo(ntpcal_dayjoin(gps_day, gps_sec)));
-		return retv;
-	}
-
-	/* So we do not trust the GPS receiver to deliver a correct date
-	 * due to the GPS epoch changes. We map the date from the
-	 * receiver into the +/-512 week interval around the receive
-	 * time in that case. This would be a tad easier with 64bit
-	 * calculations, but again, we restrict the code to 32bit ops
-	 * when possible. */
-
-	/* - make sure the GPS fractional day is normalised
-	 * Applying the offset value might have put us slightly over the
-	 * edge of the allowed range for seconds-of-day. Doing a full
-	 * division with floor correction is overkill here; a simple
-	 * addition or subtraction step is sufficient. Using WHILE loops
-	 * gives the right result even if the offset exceeds one day,
-	 * which is NOT what it's intended for! */
-	while (gps_sec >= SECSPERDAY) {
-		gps_sec -= SECSPERDAY;
-		gps_day += 1;
-	}
-	while (gps_sec < 0) {
-		gps_sec += SECSPERDAY;
-		gps_day -= 1;
-	}
-
-	/* - get unfold base: day of full recv time - 512 weeks */
-	vi64 = ntpcal_ntp_to_ntp(lfpuint(*xrecv), time(NULL));
-	rs64 = ntpcal_daysplit(vi64);
-	rcv_sec = rs64.lo;
-	rcv_day = rs64.hi - 512 * 7;
-
-	/* - take the fractional days into account
-	 * If the fractional day of the GPS time is smaller than the
-	 * fractional day of the receive time, we shift the base day for
-	 * the unfold by 1. */
-	if (   gps_sec  < rcv_sec
-	       || (gps_sec == rcv_sec && lfpfrac(retv) < lfpfrac(*xrecv)))
-		rcv_day += 1;
-
-	/* - don't warp ahead of GPS invention! */
-	if (rcv_day < g_gpsMinBase)
-		rcv_day = g_gpsMinBase;
-
-	/* - let the magic happen: */
-	adj_day = ntpcal_periodic_extend(rcv_day, gps_day, 1024*7);
-
-	/* - check if we should log a GPS epoch warp */
-	weeks = (adj_day - gps_day) / 7;
-	if (weeks != up->epoch_warp) {
-		up->epoch_warp = (short)weeks;
-		LOGIF(CLOCKINFO, (LOG_INFO,
-				  "%s Changed GPS epoch warp to %d weeks",
-				  refclock_name(peer), weeks));
-	}
-
-	/* - build result and be done */
-	setlfpuint(retv, time64lo(ntpcal_dayjoin(adj_day, gps_sec)));
-	return retv;
-}
-
 // end
