@@ -139,13 +139,13 @@ pps_start(
 
 	/*
 	 * Open PPS device. This can be any serial or parallel port and
-	 * not necessarily the port used for the associated radio.
+	 * not necessarily the port used for the associated clock.
 	 */
 	snprintf(device, sizeof(device), DEVICE, unit);
-	up->fddev = open(peer->cfg.ppspath ? peer->cfg.ppspath : device,
-		O_RDWR);
+	char *pps_path = peer->cfg.ppspath ? peer->cfg.ppspath : device;
+	up->fddev = open(pps_path, O_RDWR);
 	if (up->fddev <= 0) {
-		msyslog(LOG_ERR, "REFCLOCK: refclock_pps: %m");
+	    msyslog(LOG_ERR, "REFCLOCK: refclock_pps: %s open failed: %s", pps_path, strerror(errno));
 		return false;
 	}
 
@@ -167,8 +167,9 @@ pps_shutdown(
 	struct ppsunit *up;
 
 	up = pp->unitptr;
-	if (up->fddev > 0)
+	if (up->fddev > 0) {
 		close(up->fddev);
+	}
 	free(up);
 }
 
