@@ -12,17 +12,16 @@ TEST_TEAR_DOWN(random) {}
 
 
 TEST(random, random32) {
-	int i;
 	uint32_t ones = 0;
 	uint32_t zeros = ~0;
 
 	/* This is just a crude sanity check.
 	 * It could fail when working correctly,
 	 * but the chances are pretty small.
-	 * It won't be reproducable.  ;)
+	 * It won't be reproducible.  ;)
 	 * You can test this code by making the loop count smaller.
 	 */
-	for (i=0; i<99; i++) {
+	for (int i=0; i<99; i++) {
 		uint32_t sample = ntp_random();
 		ones |= sample;
 		zeros &= sample;
@@ -33,17 +32,16 @@ TEST(random, random32) {
 }
 
 TEST(random, random64) {
-	int i;
 	uint64_t ones = 0;
 	uint64_t zeros = ~0;
 
 	/* This is just a crude sanity check.
 	 * It could fail when working correctly,
 	 * but the chances are pretty small.
-	 * It won't be reproducable.  ;)
+	 * It won't be reproducible.  ;)
 	 * You can test this code by making the loop count smaller.
 	 */
-	for (i=0; i<99; i++) {
+	for (int i=0; i<99; i++) {
 		uint64_t sample = ntp_random64();
 		ones |= sample;
 		zeros &= sample;
