@@ -2,16 +2,35 @@
 
 #include "ntp.h"
 #include "ntp_fp.h"
-#include "refidsmear.h"
 
 #include "unity.h"
 #include "unity_fixture.h"
 
 #include <stdio.h>
 
+static l_fp	convertRefIDToLFP(uint32_t r) __attribute__((const));
+
+static l_fp
+convertRefIDToLFP(uint32_t r)
+{
+	l_fp temp = 0;
+
+	r = ntohl(r);
+
+	// printf("%03d %08x: ", (r >> 24) & 0xFF, (r & 0x00FFFFFF) );
+
+	setlfpfrac(temp, r << 10);	/* 22 fractional bits */
+
+	r = (r >> 22) & 0x3;
+	r |= ~(r & 2) + 1;
+	setlfpuint(temp, r);
+
+	return temp;
+}
+
 TEST_GROUP(refidsmear);
 
-TEST_SETUP(refidsmear) {init_lib();}
+TEST_SETUP(refidsmear) {}
 
 TEST_TEAR_DOWN(refidsmear) {}
 
