@@ -54,12 +54,12 @@ doit ()
 
 # no --disable-manpage on default and all
 doit default ""
-doit minimal "--disable-droproot --disable-dns-lookup --disable-mdns-registration --disable-manpage"
+doit minimal "--disable-droproot --disable-mdns-registration --disable-manpage"
 
 # This also tests refclocks without DEBUG
 doit classic "--enable-classic-mode --refclock=all --disable-manpage"
 
-doit all     "--enable-debug --enable-debug-gdb --enable-debug-timing --refclock=all --enable-lockclock --enable-leap-smear --enable-mssntp --enable-early-droproot $LINUX"
+doit all     "--enable-warnings --enable-debug --enable-debug-gdb --enable-debug-timing --refclock=all --enable-leap-smear --enable-mssntp --enable-early-droproot $LINUX"
 
 if [ "`which asciidoc 2>/dev/null`" != "" -a \
      "`which xsltproc 2>/dev/null`" != "" ]
